==> eam-wshub-proxyclient-11.5-10-sources.jar: net/datastream/schemas/mp_fields/SHIFTCREWID_Type.java <==

package net.datastream.schemas.mp_fields;

import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlType;
import org.openapplications.oagis_segments.DATETIME;


/**
 * <p>Classe Java pour SHIFTCREWID_Type complex type.
 * 
 * <p>Le fragment de schéma suivant indique le contenu attendu figurant dans cette classe.
 * 
 * <pre>
 * &lt;complexType name="SHIFTCREWID_Type">
 *   &lt;complexContent>
 *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *       &lt;sequence>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}SHIFTID"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}CREWID"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}STARTDATE"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}ENDDATE"/>
 *       &lt;/sequence>
 *     &lt;/restriction>
 *   &lt;/complexContent>
 * &lt;/complexType>
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "SHIFTCREWID_Type", propOrder = {
    "shiftid",
    "crewid",
    "startdate",
    "enddate"
})
public class SHIFTCREWID_Type {

    @XmlElement(name = "SHIFTID", required = true)
    protected SHIFTID_Type shiftid;
    @XmlElement(name = "CREWID", required = true)
    protected CREWID_Type crewid;
    @XmlElement(name = "STARTDATE", required = true)
    protected DATETIME startdate;
    @XmlElement(name = "ENDDATE", required = true)
    protected DATETIME enddate;

    /**
     * Obtient la valeur de la propriété shiftid.
     * 
     * @return
     *     possible object is
     *     {@link SHIFTID_Type }
     *     
     */
    public SHIFTID_Type getSHIFTID() {
        return shiftid;
    }

    /**
     * Définit la valeur de la propriété shiftid.
     * 
     * @param value
     *     allowed object is
     *     {@link SHIFTID_Type }
     *     
     */
    public void setSHIFTID(SHIFTID_Type value) {
        this.shiftid = value;
    }

    /**
     * Obtient la valeur de la propriété crewid.
     * 
     * @return
     *     possible object is
     *     {@link CREWID_Type }
     *     
     */
    public CREWID_Type getCREWID() {
        return crewid;
    }

    /**
     * Définit la valeur de la propriété crewid.
     * 
     * @param value
     *     allowed object is
     *     {@link CREWID_Type }
     *     
     */
    public void setCREWID(CREWID_Type value) {
        this.crewid = value;
    }

    /**
     * Obtient la valeur de la propriété startdate.
     * 
     * @return
     *     possible object is
     *     {@link DATETIME }
     *     
     */
    public DATETIME getSTARTDATE() {
        return startdate;
    }

    /**
     * Définit la valeur de la propriété startdate.
     * 
     * @param value
     *     allowed object is
     *     {@link DATETIME }
     *     
     */
    public void setSTARTDATE(DATETIME value) {
        this.startdate = value;
    }

    /**
     * Obtient la valeur de la propriété enddate.
     * 
     * @return
     *     possible object is
     *     {@link DATETIME }
     *     
     */
    public DATETIME getENDDATE() {
        return enddate;
    }

    /**
     * Définit la valeur de la propriété enddate.
     * 
     * @param value
     *     allowed object is
     *     {@link DATETIME }
     *     
     */
    public void setENDDATE(DATETIME value) {
        this.enddate = value;
    }

}

==> eam-wshub-proxyclient-11.7-4-sources.jar: net/datastream/schemas/mp_fields/SHIFTCREWID_Type.java <==

package net.datastream.schemas.mp_fields;

import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlType;
import org.openapplications.oagis_segments.DATETIME;


/**
 * <p>Java class for SHIFTCREWID_Type complex type.
 * 
 * <p>The following schema fragment specifies the expected content contained within this class.
 * 
 * <pre>
 * &lt;complexType name="SHIFTCREWID_Type">
 *   &lt;complexContent>
 *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *       &lt;sequence>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}SHIFTID"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}CREWID"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}STARTDATE"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}ENDDATE"/>
 *       &lt;/sequence>
 *     &lt;/restriction>
 *   &lt;/complexContent>
 * &lt;/complexType>
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "SHIFTCREWID_Type", propOrder = {
    "shiftid",
    "crewid",
    "startdate",
    "enddate"
})
public class SHIFTCREWID_Type {

    @XmlElement(name = "SHIFTID", required = true)
    protected SHIFTID_Type shiftid;
    @XmlElement(name = "CREWID", required = true)
    protected CREWID_Type crewid;
    @XmlElement(name = "STARTDATE", required = true)
    protected DATETIME startdate;
    @XmlElement(name = "ENDDATE", required = true)
    protected DATETIME enddate;

    /**
     * Gets the value of the shiftid property.
     * 
     * @return
     *     possible object is
     *     {@link SHIFTID_Type }
     *     
     */
    public SHIFTID_Type getSHIFTID() {
        return shiftid;
    }

    /**
     * Sets the value of the shiftid property.
     * 
     * @param value
     *     allowed object is
     *     {@link SHIFTID_Type }
     *     
     */
    public void setSHIFTID(SHIFTID_Type value) {
        this.shiftid = value;
    }

    /**
     * Gets the value of the crewid property.
     * 
     * @return
     *     possible object is
     *     {@link CREWID_Type }
     *     
     */
    public CREWID_Type getCREWID() {
        return crewid;
    }

    /**
     * Sets the value of the crewid property.
     * 
     * @param value
     *     allowed object is
     *     {@link CREWID_Type }
     *     
     */
    public void setCREWID(CREWID_Type value) {
        this.crewid = value;
    }

    /**
     * Gets the value of the startdate property.
     * 
     * @return
     *     possible object is
     *     {@link DATETIME }
     *     
     */
    public DATETIME getSTARTDATE() {
        return startdate;
    }

    /**
     * Sets the value of the startdate property.
     * 
     * @param value
     *     allowed object is
     *     {@link DATETIME }
     *     
     */
    public void setSTARTDATE(DATETIME value) {
        this.startdate = value;
    }

    /**
     * Gets the value of the enddate property.
     * 
     * @return
     *     possible object is
     *     {@link DATETIME }
     *     
     */
    public DATETIME getENDDATE() {
        return enddate;
    }

    /**
     * Sets the value of the enddate property.
     * 
     * @param value
     *     allowed object is
     *     {@link DATETIME }
     *     
     */
    public void setENDDATE(DATETIME value) {
        this.enddate = value;
    }

}
